#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oegraphsim


# @ <SNIPPET-SIM-FUNC-1>
class SimpsonSimFunc(oegraphsim.OESimFuncBase):

    def __call__(self, fpA, fpB):
        onlyA, onlyB, bothAB, neitherAB = oechem.OEGetBitCounts(fpA, fpB)
        if onlyA + onlyB == 0:
            return 1.0
        if bothAB == 0:
            return 0.0
        sim = float(bothAB)
        sim /= min(float(onlyA + bothAB), float(onlyB + bothAB))
        return sim

    def GetSimTypeString(self):
        return "Simpson"

    def CreateCopy(self):
        return SimpsonSimFunc().__disown__()
# @ </SNIPPET-SIM-FUNC-1>


smiles = ["c1ccc2c(c1)c(c(oc2=O)OCCSC(=N)N)Cl",
          "COc1cc2ccc(cc2c(=O)o1)NC(=N)N"]

# @ <SNIPPET-SIM-FUNC-2>
fpdb = oegraphsim.OEFPDatabase(oegraphsim.OEFPType_Path)
fpdb.SetSimFunc(SimpsonSimFunc())
# @ </SNIPPET-SIM-FUNC-2>

mol = oechem.OEGraphMol()
for smi in smiles:
    mol.Clear()
    oechem.OESmilesToMol(mol, smi)
    fpdb.AddFP(mol)

query = oechem.OEGraphMol()
oechem.OESmilesToMol(query, "COc1c(c2ccc(cc2c(=O)o1)NC(=N)N)Cl")
for score in fpdb.GetScores(query):
    print("%.3f" % score.GetScore())



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# Cache as much as possible on the molecule to improve the performance
# of starting a server from scratch. Also cull to desired number of
# conformers if requested.

import os
import sys

from openeye import oechem
from openeye import oefastrocs

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))


def TrimConformers(mol, maxConfs):
    for i, conf in enumerate(mol.GetConfs()):
        if i >= maxConfs:
            mol.DeleteConf(conf)


def main(argv=[__name__]):
    if len(argv) != 3 and len(argv) != 4:
        oechem.OEThrow.Usage("%s <database.oeb> <prepped_database.oeb> [max_confs]" % argv[0])

    maxConfs = None
    if len(argv) == 4:
        maxConfs = int(argv[3])
        if maxConfs < 1:
            oechem.OEThrow.Fatal("Illegal number of conformer requested %u", maxConfs)

    # input - preserve rotor-offset-compression
    ifs = oechem.oemolistream()
    oechem.OEPreserveRotCompress(ifs)

    if not ifs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])

    # output - use PRE-compress for smaller files (no need to .gz the file)
    ofs = oechem.oemolostream()
    oechem.OEPRECompress(ofs)
    if not ofs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[2])

    dots = oechem.OEDots(10000, 200, "molecules")
    for mol in ifs.GetOEMols():
        if maxConfs is not None:
            TrimConformers(mol, maxConfs)

        oefastrocs.OEPrepareFastROCSMol(mol)
        oechem.OEWriteMolecule(ofs, mol)
        dots.Update()

    dots.Total()
    ofs.close()

    print("Indexing %s" % argv[2])
    if not oechem.OECreateMolDatabaseIdx(argv[2]):
        oechem.OEThrow.Fatal("Failed to index %s" % argv[2])

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
import sys

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


def main(argv=[__name__]):

    # @ <SNIPPET-OECONFIGURECOLOR>
    itf = oechem.OEInterface()
    oedepict.OEConfigureColor(itf, "mycolor", "c", "Example of using OEConfigureColor", "blue")
    # @ </SNIPPET-OECONFIGURECOLOR>

    if oechem.OECheckHelp(itf, argv):
        return True

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    color = oechem.OEGetColor(itf, "mycolor")
    print(str(color))


if __name__ == "__main__":
    sys.exit(main(sys.argv))
